svn commit: samba r17276 - in branches/SAMBA_3_0/source/locking: .

jra at samba.org jra at samba.org
Thu Jul 27 15:23:47 GMT 2006


Author: jra
Date: 2006-07-27 15:23:46 +0000 (Thu, 27 Jul 2006)
New Revision: 17276

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=17276

Log:
Don't change the POSIX lock ref count if posix locking = no.
Jeremy.

Modified:
   branches/SAMBA_3_0/source/locking/brlock.c


Changeset:
Modified: branches/SAMBA_3_0/source/locking/brlock.c
===================================================================
--- branches/SAMBA_3_0/source/locking/brlock.c	2006-07-27 14:47:28 UTC (rev 17275)
+++ branches/SAMBA_3_0/source/locking/brlock.c	2006-07-27 15:23:46 UTC (rev 17276)
@@ -1326,8 +1326,8 @@
 		}
 	}
 
-	if (num_deleted_windows_locks) {
-		/* Reduce the Windows lock reference count on this dev/ino pair. */
+	if(lp_posix_locking(fsp->conn->cnum) && num_deleted_windows_locks) {
+		/* Reduce the Windows lock POSIX reference count on this dev/ino pair. */
 		reduce_windows_lock_ref_count(fsp, num_deleted_windows_locks);
 	}
 }



More information about the samba-cvs mailing list